References
============

Please consider citing the following references if FastMBAR is used in your projects.

1. Xinqiang Ding, Jonah Z. Vilseck, Charles L. Brooks III. (2019). `Fast Solver for Large Scale Multistate Bennett Acceptance Ratio Equations. <https://doi.org/10.1021/acs.jctc.8b01010>`_  *J. Chem. Theory Comput.*

2. Xinqiang Ding, Jonah Z. Vilseck, Ryan L. Hayes, Charles L. Brooks III. (2017). `Gibbs Sampler-based λ-dynamics and Rao–Blackwell Estimator for Alchemical Free Energy Calculation. <https://doi.org/10.1021/acs.jctc.7b00204>`_  *J. Chem. Theory Comput.*
   
3. Shirts, Michael R., and John D. Chodera. (2008) `Statistically Optimal Analysis of Samples from Multiple Equilibrium States. <https://doi.org/10.1063/1.2978177>`_ *J. Chem. Phys.*

4. Bennett, Charles H. (1976) `Efficient Estimation of Free Energy Differences from Monte Carlo Data. <https://doi.org/10.1016/0021-9991(76)90078-4>`_ J. Comput. Phys.


